#
# spec file for package form
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Documentation building fails due to LaTeX errors; disable for now
%define with_doc 0

%define reldate 20190212
Name:           form
Version:        4.2.1
Release:        bp153.1.15
Summary:        A Symbolic Manipulation System
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
Url:            https://github.com/vermaseren/form/
Source0:        https://github.com/vermaseren/form/archive/v%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  git
BuildRequires:  gmp-devel
BuildRequires:  libtool
BuildRequires:  openmpi-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib)
%if %{with_doc}
BuildRequires:  texlive-tex4ht
BuildRequires:  tex(adjustbox.sty)
BuildRequires:  tex(amssymb.sty)
BuildRequires:  tex(calc.sty)
BuildRequires:  tex(caption.sty)
BuildRequires:  tex(courier.sty)
BuildRequires:  tex(fancyhdr.sty)
BuildRequires:  tex(fixltx2e.sty)
BuildRequires:  tex(fontenc.sty)
BuildRequires:  tex(geometry.sty)
BuildRequires:  tex(graphicx.sty)
BuildRequires:  tex(helvet.sty)
BuildRequires:  tex(hyperref.sty)
BuildRequires:  tex(ifpdf.sty)
BuildRequires:  tex(inputenc.sty)
BuildRequires:  tex(makeidx.sty)
BuildRequires:  tex(multicol.sty)
BuildRequires:  tex(multirow.sty)
BuildRequires:  tex(natbib.sty)
BuildRequires:  tex(sectsty.sty)
BuildRequires:  tex(textcomp.sty)
BuildRequires:  tex(tocloft.sty)
BuildRequires:  tex(wasysym.sty)
BuildRequires:  tex(xcolor.sty)
%endif
Recommends:     %{name}-doc = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FORM is a Symbolic Manipulation System. It reads symbolic expressions from files
and executes symbolic/algebraic transformations upon them. The answers are
returned in a textual mathematical representation. As its landmark feature, the
size of the considered expressions in FORM is only limited by the available
disk space and not by the available RAM.

%package doc
Summary:        Additional documentation for %{name} - A Symbolic Manipulation System
Group:          Documentation/HTML

%description doc
FORM is a Symbolic Manipulation System. It reads symbolic expressions from files
and executes symbolic/algebraic transformations upon them. The answers are
returned in a textual mathematical representation. As its landmark feature, the
size of the considered expressions in FORM is only limited by the available
disk space and not by the available RAM.

This package provides additional documentation for %{name}.

%prep
%setup -q

# REPLACE __DATE__ BY %%{reldate} USED TO TAG THE SOURCE TARBALL
sed -i "s/PRODUCTIONDATE __DATE__/PRODUCTIONDATE %{reldate}/" sources/form3.h
sed -i "s/PRODUCTIONDATE __DATE__/PRODUCTIONDATE %{reldate}/" configure.ac

%build
if [ -f %{_libdir}/mpi/gcc/openmpi/bin/mpivars.sh ]; then
  source %{_libdir}/mpi/gcc/openmpi/bin/mpivars.sh
fi

sed -i "s|-march=native||g" configure.ac
autoreconf -fvi
%configure --enable-parform
make %{?_smp_mflags}

%if %{with_doc}
# MAKE DOCUMENTATION
pushd doc
make %{?_smp_mflags} pdf
make %{?_smp_mflags} html
popd
%endif

%install
%make_install

%fdupes -s doc

%files
%doc AUTHORS README.md COPYING
%if %{with_doc}
%doc doc/manual/manual.pdf
%doc doc/manual/html/
%endif
%{_bindir}/form
%{_bindir}/tform
%{_bindir}/parform
%{_mandir}/man1/form.1%{ext_man}

%if %{with_doc}
%files doc
%doc doc/doxygen/html/
%doc doc/devref/devref.pdf
%doc doc/devref/html/
%endif

%changelog
* Fri Mar 15 2019 Atri B <badshah400@gmail.com>
- Update to version 4.2.1:
  * See
    https://github.com/vermaseren/form/wiki/Release-Notes-Form-4.2.1
    for a full list of changes.
  * Bug fixes:
  - Replaced the obsolete ftime() function with clock_gettime()
    when the latter is available (gh#vermaseren/form#276)
  - Improved the algorithms of division and reminder for
    non-monic multivariate polynomials (gh#vermaseren/form#281)
  - Removed an inefficiency when many expressions are defined
  - Improved the merge sort inside memory based on Timsort
  - Fixed a bug that caused a pattern matching failure for
    restricted numbers in ex-Polyratfun (gh#vermaseren/form#55)
  - Fixed crashes in routines for gzip decompression
    (gh#vermaseren/form#95)
  - Fixed content_ for polynomials with constant terms
    (gh#vermaseren/form#185)
  - Fixed some portability issues (gh#vermaseren/form#217,
    gh#vermaseren/form#223)
  - Fixed corrupted characters from the prepreocessor calculator
    when the result is the most negative integer
    (gh#vermaseren/form#219)
  - Fixed a crash on accessing the first
    gh#vermaseren/form#factdollar factor of an integer
    (gh#vermaseren/form#222)
  - Fixed memory leaks in routines for gzip compression
    (gh#vermaseren/form#248)
  - Fixed a memory bug for local $-variables in TFORM
    (gh#vermaseren/form#253)
  - Fixed a bug that made gcd_ give wrong results
    (gh#vermaseren/form#258)
  - Fixed a bug in the polynomial GCD routine
    (gh#vermaseren/form#260)
  - Fixed a wrong "Division by zero" runtime error by mul_(x,0)
    (gh#vermaseren/form#261)
  - Fixed a bug that caused wrong results in code optimization
    (gh#vermaseren/form#272)
  - Fixed transform,addargs for the case that the result becomes
    0 (gh#vermaseren/form#277)
  - Fixed some bug in LHS patterns with poly(rat)fun and symbols
  - Fixed the problem that content_ did not handle functions
    properly
- Disable documentation due to LaTeX errors.
* Tue Jul 10 2018 bwiedemann@suse.com
- compile independent of build system CPU (boo#1100677)
* Wed Oct 25 2017 badshah400@gmail.com
- Setup MPI environment before building.
* Sun Jul  9 2017 badshah400@gmail.com
- Update to version 4.2.0:
  + See
    https://github.com/vermaseren/form/wiki/Release-Notes---Form-4.2.0
    for list of changes.
- Drop form-devref-pdf.patch; incorporated upstream.
- Add BuildRequires on git, required to ascertain revision id.
* Fri Dec  9 2016 badshah400@gmail.com
- Initial package.
- Add form-devref-pdf.patch to fix a typo preventing devref PDF
  documentation from generating.
- Add %%{name}-rpmlintrc file to suppress warning regarding missing
  man pages: upstream doesn't supply these.
